package org.nl.hand.service;


import org.nl.hand.dto.HeadDto;
import org.nl.hand.dto.HeadInstDto;
import org.nl.hand.dto.HeadTaskDto;

import java.util.Map;

/**
 * @Author : TuQiang
 * @create 2024/4/2 10:19
 */
public interface HandService {


    Map<String, Object> queryPointByArea(String region_code);

    /**
     * 手持创建任务
     *
     * @param dto
     * @return
     */
    Map<String, Object> callTask(HeadDto dto);

    Map<String, Object> queryArea();

    Map<String, Object> queryInst(HeadInstDto dto);

    Map<String, Object> instOpt(HeadInstDto dto) throws Exception;

    Map<String, Object> querytasks(HeadTaskDto dto);

    Map<String, Object> taskOperation(HeadTaskDto dto);

}
